#!/bin/bash

# This merges templates together
merge_template() {
    cur_dir=${PWD}
    main_template=${1}
    addin_template=${2}
    new_template=${3}

    if [ -n "${addin_template}" ]; then
      ntmp_dir=$(mktemp -d template.XXXXX --tmpdir=${TMPDIR:-/tmp})
      cd ${ntmp_dir}

      # Split the base template "ADDIN_HERE"
      awk '/ADDIN_HERE/{n++}{print >"template" n ".txt" }' \
            ${main_template} ||
                fail "failed to split template!"

      # Combine the split template with the addin in the middle
      cat template.txt \
          ${addin_template} \
          template1.txt \
            > ${new_template}

      # Do some variable replacement
      sed -e "s,ADDIN_HERE,# END Addins,g" \
          -e "s,%%PPA%%,${PPA},g" \
          -e "s,%%PROPOSED%%,${PROPOSED:-0},g" \
          -i  ${new_template} ||
            fail "Unable to finalize template!"

    else
        "${main_template}" "${new_template}"
    fi

    # Remove the temp directory if it exists
    [ -n "${ntmp_dir}" ] && rm -rf "${ntmp_dir}"

    # Get back to where we started
    cd ${cur_dir}
}
