#!/bin/bash

# Set default umask
umask 022

# Read in the common files
source "${kvm}/functions/common"
source "${kvm}/functions/retry"

# Apply the build stuff
find . -iname "*build_properties" | xargs -I FILE cp FILE .
[ -e "build_properties" ] &&
    source build_properties ||
    fail "Failed to read build_properties. I don't know what I'm doing!"

[ -e failed ] && rm
[ -e success ] && rm

# Copy the target disk image
case ${SUITE} in
    precise|trusty|wily|xenial)
        disk_orig="${SUITE}-server-cloudimg-${ARCH}-disk1.img"
        builder_img=/srv/builder/images/trusty-builder-latest.img
        ;;
    *)
        disk_orig="${SUITE}-server-cloudimg-${ARCH}.img"
        builder_img=/srv/builder/images/yakkety-builder-latest.img
        ;;
esac

disk_cp="${disk_orig//cloudimg/cloudimg-builder-$(date +%Y%m%d)}"
disk_root="/srv/ec2-images/${SUITE}/${SERIAL:-current}"
disk_working="${WORKSPACE}/${disk_cp}"
raw_f="${WORKSPACE}/raw_f-$(date +%s).img"

cp "${disk_root}/${disk_orig}" "${disk_working}" ||
    fail "Unable to copy ${disk_orig} from ${disk_root}"

qemu-img resize "${disk_working}" 5G ||
    fail "unable to resize disk"

# Launch KVM to do the work
${kvm}/launch_kvm.sh \
        --id "${ARCH}-${BUILD_ID}" \
        --user-data "${kvm}/config/cloud-vps.cfg" \
        --cloud-config "${kvm}/templates/img-update.tmpl" \
        --extra-disk "${disk_working}" \
        --disk-gb 5 \
        --raw-disk "${raw_f}" \
        --raw-size 1 \
        --img-url ${builder_img} ||
            fail "KVM instance failed to build image."

# Remove the results
rm "${raw_f}" || /bin/true

# Compress it down...
mv "${disk_working}" "${disk_working}.new"
qemu-img convert "${disk_working}.new" -c -O qcow2 "${disk_working}" ||
    fail "Failed to create compressed image"

rm "${disk_working}.new"

