#!/bin/bash
#
# Clean up MAAS2 v2/v3 builds/streams
#
my_dir="$(dirname $0)"
my_p_dir="$(dirname $my_dir)"
source ${my_p_dir}/functions/common
source ${my_p_dir}/functions/bzr_check.sh

# Number of builds to publish in the stream
MAX_BUILDS=${MAX_BUILDS:-3}
# Number of days to keep files not referenced in the stream data
REAP_AGE=${REAP_AGE:-2d}

WORKSPACE=${WORKSPACE:-$PWD}
OUTDIR=${JENKINS_HOME:?}/.config/MAASv2_Cleaner/
DAILY_ROOT=/srv/maas-images/ephemeral-v2/daily/
RELEASE_ROOT=/srv/maas-images/ephemeral-v2/releases/
INDEX_PATH=streams/v1/index.json

# Local checkouts
sstreams=${WORKSPACE}/sstreams
maasv2=${WORKSPACE}/maasv2
check_branch ${BZR_SIMPLESTREAMS:-lp:simplestreams} ${sstreams}
check_branch ${BZR_MAASv2:-lp:maas-images} ${maasv2}

for METADATA_ROOT in /srv/maas-images/ephemeral-v2/daily/ \
                     /srv/maas-images/ephemeral-v3/daily/;  do
    case $METADATA_ROOT in
        *v2*)
            orphan_json="${OUTDIR}/daily.json"
            ;;
        *v3*)
            orphan_json="${OUTDIR}/daily-v3.json"
            ;;
        *)
            echo "Unexpected METADATA_ROOT"
            exit 1
            ;;
    esac
    run PYTHONPATH=${sstreams}:${maasv2} \
        ${maasv2}/bin/meph2-util clean-md \
            ${MAX_BUILDS} ${METADATA_ROOT}/${INDEX_PATH}

    run PYTHONPATH=${sstreams}:${maasv2} \
        ${maasv2}/bin/meph2-util find-orphans \
            "${orphan_json}" \
            ${METADATA_ROOT} ${METADATA_ROOT}/${INDEX_PATH}

    run PYTHONPATH=${sstreams}:${maasv2} \
        ${maasv2}/bin/meph2-util reap-orphans \
            --older ${REAP_AGE} \
            "${orphan_json}" \
            ${METADATA_ROOT}
done
