#!/bin/bash -x

fail() { [ $# -eq 0 ] || echo "$@"; exit 1; }

[ -z "${SERIAL}" -a -z "${SUITE}" -a -e "build_properties" ] && {
    source build_properties ||
    fail "Failed to read build_properties.";
}

# Read in the common functions
my_dir="$( cd "$( dirname "$0" )" && pwd )"
base_dir=$(dirname ${my_dir})
export PATH="${base_dir}:${my_dir}:${PATH}"
source "${base_dir}/functions/locker"
source "${base_dir}/functions/common"
source "${base_dir}/functions/retry"
source ${my_dir}/build_lib.sh
select_build_config

case "${STREAM:?}" in
    daily)    build_f="/srv/ec2-images/${SUITE}/${SERIAL}";
              base_name="${SUITE}-server-cloudimg"
              ;;
    *)        fail "Unknown/unsupported stream ${STREAM}.";;
esac

export WORKSPACE="${WORKSPACE:-$WORKSPACE_R}"
out_f="${WORKSPACE:?}/maas-${SUITE}-${STREAM}-config.sh"
raw_f="${WORKSPACE}/${SUITE}-output.raw"

export maas_branch="${MAAS_BRANCH:?}"

touch ${WORKSPACE}/maasv3
tar cvf ${query_t} ${WORKSPACE}/maasv3

# Construct the right template
maas_config.sh \
    --distro "${SUITE}" \
    --stream "${STREAM}" \
    --template "${kvm_builder}/templates/img-maasv3.tmpl" \
    --base-name "${base_name}" \
    --local "${build_f}" \
    --serial "${SERIAL}" \
    --out "${out_f}" \
    --maas-branch "${maas_branch}" \
    --out_d "/tmp/maas_final" ||
    fail "Failed to configure KVM instance for building"

ci_cfg="${kvm_builder}/config/cloud-maasv3.cfg"
[ "$(uname -m)" == "ppc64" ] && ci_cfg="${kvm_builder}/config/cloud-trusty-pp64el.cfg"

# Launch KVM to do the work
launch_kvm.sh \
    --id ${BUILD_ID} \
    --user-data "${out_f}" \
    --cloud-config "${ci_cfg}" \
    --extra-disk "${query_t}" \
    --disk-gb 50 \
    --raw-disk "${raw_f}" \
    --raw-size 20 \
    --mem 1G \
    --img-url ${BUILDER_CLOUD_IMAGE} ||
        fail "KVM instance failed to build image."

# Extract the result set
tar -xvvf "${raw_f}" ||
    fail "Failed to extract information from instance"
