#!/bin/bash -x

# Add in the retry stub
source "${kvm}/functions/retry"
source "${kvm}/functions/common"

# Exit if trigger job does not want this published
[ "${PUBLISH_IMAGE}" -eq 0 ] && exit 0

# Set the build directories
WORK_D="/srv/ec2-images/${BUILD_TYPE}/${SUITE}/${SERIAL}"
[ "${TEST_BUILD}" -eq 1 ] && WORK_D="/srv/ec2-images/test_builds/${BUILD_TYPE}/${SUITE}/${SERIAL}"
[ "${SANDBOX_BUILD}" -eq 1 ] && WORK_D="/srv/ec2-images/sandbox/${BUILD_TYPE}/${SUITE}/${SERIAL}"

# Handle the special case of HWE builds. Otherwise they get the names of server
# and things don't go well.
[[ "${HWE_SUFFIX}" =~ hwe ]] &&
    WORK_D="${WORK_D}/${HWE_SUFFIX}" &&
    BUILD_TYPE="${BUILD_TYPE}-${HWE_SUFFIX}"


echo "Using ${WORK_D} as the directory"
[ -e "${WORK_D}" ] || { echo "Working directory does not exist!"; exit 1; }

ec2_pub="${PWD}/ec2-publishing-scripts"

# Check out the scripts needed
[ -e "${ec2_pub}" ] && rm -rf "${ec2_pub}"
bzr branch "${EC2_PUB_SCRIPTS}" "${ec2_pub}"

# Add some elements to the path
VMBUILDER_PATH="${VMBUILDER_PATH:-/srv/builder/vmbuilder}"
VMBUILDER_BIN="${VMBUILDER_PATH}/bin"
XC2_PATH="${VMBUILDER_PATH}/ec2-daily/xc2"
export PUBLISH_SCRIPTS="${PUBLISH_SCRIPTS:-$VMBUILDER_PATH/ec2-publishing-scripts}"
export PATH="${VMBUILDER_BIN}:${VMBUILDER_BIN}:${VMBUILDER_PATH}:${XC2_PATH}:${PATH}"
export HOME="/srv/builder/vmbuilder"
export CDIMAGE_ROOT="${CDIMAGE_ROOT:-/srv/builder/cdimage}"
export EC2_PUB_LOC="${ec2_pub}"

ec2publish() {
    # Run the publisher job
    ${kvm}/ec2_publisher.sh \
           ${SUITE} \
           ${SERIAL} \
           ${BUILD_TYPE} \
           ${WORK_D} \
           ${TEST_BUILD} \
           ${SANDBOX_BUILD} \
           ${ALLOW_EXISTING}
}

# Retry the publishing up to 3 times
retry 6 120 ec2publish ||
    fail "Failed three attempts to publish EC2 images!"

# Add the new daily to the tracker
#exec_tracker=${ADD_TO_TRACKER:-0}
#[ "${exec_tracker}" -eq 1 ] && {
#    ${kvm}/tracker.sh daily ${SUITE} ${SERIAL} &&
#         exit $? || fail "Unable to execute tracker!"
#    }
#
#exit 0
